Learn R Programming

covid19france (version 0.1.0)

get_info_covid19france: Get info about this dataset

Description

Get info about this dataset

Usage

get_info_covid19france()

Arguments

Value

A tibble with information about where the data is pulled from, details about the dataset, what the data types are, etc.

Examples

Run this code
# NOT RUN {
get_info_covid19france()
# }

Run the code above in your browser using DataLab