powered by
Get info about this dataset
get_info_covid19france()
A tibble with information about where the data is pulled from, details about the dataset, what the data types are, etc.
# NOT RUN { get_info_covid19france() # }
Run the code above in your browser using DataLab